@@ -1,6 +1,7 @@
 import json
 
 import pandas as pd
+import numpy as np
 import pytest
 
 import iglu_python as iglu
@@ -48,6 +49,9 @@ def test_above_percent_iglu_r_compatible(scenario):
     expected_results = scenario["results"]
     expected_df = pd.DataFrame(expected_results)
     expected_df = expected_df.reset_index(drop=True)
+    pd.set_option('future.no_silent_downcasting', True)
+    expected_df = expected_df.replace({None: np.nan})
+
 
     # Compare DataFrames with precision to 0.001
     pd.testing.assert_frame_equal(
