@@ -48,6 +48,10 @@ def test_modd_iglu_r_compatible(scenario):
     expected_df = pd.DataFrame(expected_results)
     expected_df = expected_df.reset_index(drop=True)
 
+    pd.set_option('future.no_silent_downcasting', True)
+    expected_df = expected_df.replace({None: np.nan})
+
+
     # Compare DataFrames with precision to 0.001 for numeric columns
     pd.testing.assert_frame_equal(
         result_df,
